using System;
using UnityEngine;
using UnityEngine.UI;
using System.Collections;
using System.Collections.Generic;
using SimpleJSON;
using MVR.FileManagementSecure;

namespace McKlinton
{

    public static class Utils
    {
        public static string PluginDataDirectoryLocalPath = "Custom\\PluginData\\McKlinton\\";

        // Thanks to MacGruber for this function, borrowed from his Utils.cs
        // Get path prefix of the package that contains our plugin.
        public static string GetPackagePath(MVRScript self)
        {
            string id = self.name.Substring(0, self.name.IndexOf('_'));
            string filename = self.manager.GetJSON()["plugins"][id].Value;
            int idx = filename.IndexOf(":/");
            if (idx >= 0)
                return filename.Substring(0, idx + 2);
            else
                return string.Empty;
        }

        public static string GetPackagePluginDataPath(MVRScript self)
        {
            var packagePath = GetPackagePath(self);
            var pluginDataPath = PluginDataDirectoryLocalPath;
            if (packagePath != string.Empty)
            {
                pluginDataPath = packagePath + PluginDataDirectoryLocalPath;
            }
            return pluginDataPath;
        }
        public static JSONClass Vector3ToJSON(Vector3 vector)
        {
            JSONClass json = new JSONClass();
            json["x"] = new JSONData(vector.x);
            json["y"] = new JSONData(vector.y);
            json["z"] = new JSONData(vector.z);
            return json;
        }

         public static JSONClass QuaternionToJSON(Quaternion quaternion)
        {
            JSONClass json = new JSONClass();
            json["x"] = new JSONData(quaternion.x);
            json["y"] = new JSONData(quaternion.y);
            json["z"] = new JSONData(quaternion.z);
            json["w"] = new JSONData(quaternion.w);
            return json;
        }
        public static Vector3 JSONToVector3(JSONClass json)
        {
            return new Vector3(json["x"].AsFloat, json["y"].AsFloat, json["z"].AsFloat);
        }

        public static Quaternion JSONToQuaternion(JSONClass json)
        {
            return new Quaternion(json["x"].AsFloat, json["y"].AsFloat, json["z"].AsFloat, json["w"].AsFloat);
        }

        public static List<string> GetKeyCodes()
        {
            List<string> keyCodes = new List<string>();
            foreach (KeyCode keyCode in Enum.GetValues(typeof(KeyCode)))
            {
                keyCodes.Add(keyCode.ToString());
            }
            return keyCodes;
        }

        public static KeyCode GetKeyCode(string keyCode)
        {
            return (KeyCode)Enum.Parse(typeof(KeyCode), keyCode);
        }
    }
}